@@ -8,8 +8,10 @@ package Text::Layout::PDFAPI2;
 
 use parent 'Text::Layout';
 use Carp;
+use List::Util qw(max);
 
 my $hb;
+my $fc;
 
 #### API
 sub new {
@@ -116,9 +118,19 @@ sub render {
 			$fragment->{color},
 		       ),
 		  ) if 0;
-	    $text->translate( $x, $y-$fragment->{base}-$bl );
-	    $text->text( $fragment->{text} );
-	    $x += $font->width( $fragment->{text} ) * $fragment->{size};
+	    my $t = $fragment->{text};
+	    my $maxw = 0;
+	    my $y = $y-$fragment->{base}-$bl;
+	    while ( $t ne "" ) {
+		( $t, my $rest ) = split( /\n/, $t, 2 );
+		my $sz = $fragment->{size} || $self->{_currentsize};
+		$text->translate( $x, $y );
+		$text->text($t);
+		$maxw = max($font->width($t) * $sz, $maxw);
+		$y -= $sz;
+		$t = $rest // "";
+	    }
+	    $x += $maxw;
 	}
     }
     $text->restore;
@@ -187,8 +199,11 @@ sub bbox {
 #### API
 sub load_font {
     my ( $self, $font ) = @_;
-    return $self->{cache}->{$font}
-      if $self->{cache}->{$font};
+
+    if ( $fc->{$font} ) {
+	# warn("Loaded font $font (cached)\n");
+	return $fc->{$font};
+    }
 
     my $ff;
     if ( $font =~ /\.[ot]tf$/ ) {
@@ -205,7 +220,7 @@ sub load_font {
     croak( "Cannot load font: ", $font, "\n", $@ ) unless $ff;
     # warn("Loaded font: $font\n");
     $self->{font} = $ff;
-    $self->{cache}->{$font} = $ff;
+    $fc->{$font} = $ff;
     return $ff;
 }
 
